@@ -13,6 +13,7 @@ use Mojolicious::Routes;
 use Mojolicious::Sessions;
 use Mojolicious::Static;
 use Mojolicious::Types;
+use Mojolicious::Validator;
 use Scalar::Util qw(blessed weaken);
 use Time::HiRes 'gettimeofday';
 
@@ -36,12 +37,13 @@ has secret   => sub {
   # Default to moniker
   return $self->moniker;
 };
-has sessions => sub { Mojolicious::Sessions->new };
-has static   => sub { Mojolicious::Static->new };
-has types    => sub { Mojolicious::Types->new };
+has sessions  => sub { Mojolicious::Sessions->new };
+has static    => sub { Mojolicious::Static->new };
+has types     => sub { Mojolicious::Types->new };
+has validator => sub { Mojolicious::Validator->new };
 
 our $CODENAME = 'Top Hat';
-our $VERSION  = '4.40';
+our $VERSION  = '4.42';
 
 sub AUTOLOAD {
   my $self = shift;
@@ -72,7 +74,8 @@ sub new {
   $r->hide(qw(app continue cookie finish flash handler match on param));
   $r->hide(qw(redirect_to render render_exception render_later render_maybe));
   $r->hide(qw(render_not_found render_static rendered req res respond_to));
-  $r->hide(qw(send session signed_cookie stash tx url_for write write_chunk));
+  $r->hide(qw(send session signed_cookie stash tx url_for validation write));
+  $r->hide(qw(write_chunk));
 
   # Check if we have a log directory
   my $mode = $self->mode;
@@ -364,6 +367,14 @@ L<Mojolicious::Types> object.
   # Add custom MIME type
   $app->types->type(twt => 'text/tweet');
 
+=head2 validator
+
+  my $validator = $app->validator;
+  $app          = $app->validator(Mojolicious::Validator->new);
+
+Validate form data, defaults to a L<Mojolicious::Validator> object. Note that
+this attribute is EXPERIMENTAL and might change without warning!
+
 =head1 METHODS
 
 L<Mojolicious> inherits all methods from L<Mojo> and implements the following
@@ -795,6 +806,8 @@ Ilya Chesnokov
 
 James Duncan
 
+Jan Henning Thorsen
+
 Jan Jona Javorsek
 
 Jan Schmidt
